
#ifndef TEXTEDITOR_EXPORT_H
#define TEXTEDITOR_EXPORT_H

#ifdef TEXTEDITOR_STATIC_DEFINE
#  define TEXTEDITOR_EXPORT
#  define TEXTEDITOR_NO_EXPORT
#else
#  ifndef TEXTEDITOR_EXPORT
#    ifdef MauiKitTextEditor4_EXPORTS
        /* We are building this library */
#      define TEXTEDITOR_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define TEXTEDITOR_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef TEXTEDITOR_NO_EXPORT
#    define TEXTEDITOR_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef TEXTEDITOR_DEPRECATED
#  define TEXTEDITOR_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TEXTEDITOR_DEPRECATED_EXPORT
#  define TEXTEDITOR_DEPRECATED_EXPORT TEXTEDITOR_EXPORT TEXTEDITOR_DEPRECATED
#endif

#ifndef TEXTEDITOR_DEPRECATED_NO_EXPORT
#  define TEXTEDITOR_DEPRECATED_NO_EXPORT TEXTEDITOR_NO_EXPORT TEXTEDITOR_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TEXTEDITOR_NO_DEPRECATED
#    define TEXTEDITOR_NO_DEPRECATED
#  endif
#endif

#endif /* TEXTEDITOR_EXPORT_H */
